##  Quality Seal
A quality seal ensures the overall integrity and quality of data on fact sheets. It assigns accountability to the responsible or accountable subscribers to approve the quality of a fact sheet whenever other users make any changes to it.
When the quality seal is broken, it triggers a Check needed status at the top of the fact sheet, prompting the responsible individual to verify the data and approve the quality seal. The quality seal can also be manually broken if necessary, indicating that the information on the fact sheet needs to be reviewed or updated. This feature ensures that any changes made to a fact sheet are verified for accuracy and completeness.
To learn how to use and configure the quality seal, see [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.").
